@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Metacity main() */
 
 /* 
@@ -363,7 +365,7 @@ main (int argc, char **argv)
     }
   
   if (!meta_ui_have_a_theme ())
-    meta_fatal (_("Could not find a theme! Be sure %s exists and contains the usual themes."),
+    meta_fatal (_("Could not find a theme! Be sure %s exists and contains the usual themes.\n"),
                 METACITY_DATADIR"/themes");
   
   /* Connect to SM as late as possible - but before managing display,
