@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Metacity X managed windows */
 
 /* 
@@ -118,13 +120,16 @@ struct _MetaWindow
   int initial_workspace;  
   
   /* Initial timestamp property */
-  Time initial_timestamp;  
+  guint32 initial_timestamp;  
   
   /* Whether we're maximized */
   guint maximized_horizontally : 1;
   guint maximized_vertically : 1;
+
+  /* Whether we have to maximize/minimize after placement */
   guint maximize_horizontally_after_placement : 1;
   guint maximize_vertically_after_placement : 1;
+  guint minimize_after_placement : 1;
 
   /* Whether we're shaded */
   guint shaded : 1;
@@ -312,7 +317,7 @@ struct _MetaWindow
 
   /* set to the most recent user-interaction event timestamp that we
      know about for this window */
-  Time net_wm_user_time;
+  guint32 net_wm_user_time;
   
   /* The size we set the window to last (i.e. what we believe
    * to be its actual size on the server). The x, y are
@@ -381,7 +386,8 @@ MetaWindow* meta_window_new_with_attrs     (MetaDisplay *display,
                                             Window       xwindow,
                                             gboolean     must_be_viewable,
                                             XWindowAttributes *attrs);
-void        meta_window_free               (MetaWindow  *window);
+void        meta_window_free               (MetaWindow  *window,
+                                            guint32      timestamp);
 void        meta_window_calc_showing       (MetaWindow  *window);
 void        meta_window_queue_calc_showing (MetaWindow  *window);
 void        meta_window_minimize           (MetaWindow  *window);
@@ -395,8 +401,10 @@ void        meta_window_unmaximize         (MetaWindow        *window,
                                             MetaMaximizeFlags  directions);
 void        meta_window_make_above         (MetaWindow  *window);
 void        meta_window_unmake_above       (MetaWindow  *window);
-void        meta_window_shade              (MetaWindow  *window);
-void        meta_window_unshade            (MetaWindow  *window);
+void        meta_window_shade              (MetaWindow  *window,
+                                            guint32      timestamp);
+void        meta_window_unshade            (MetaWindow  *window,
+                                            guint32      timestamp);
 void        meta_window_change_workspace   (MetaWindow  *window,
                                             MetaWorkspace *workspace);
 void        meta_window_stick              (MetaWindow  *window);
@@ -404,10 +412,10 @@ void        meta_window_unstick            (MetaWindow  *window);
 
 void        meta_window_activate           (MetaWindow  *window,
                                             guint32      current_time);
-void        meta_window_activate_with_workspace (MetaWindow *window,
-                                            guint32          current_time,
-                                            MetaWorkspace   *workspace);   
-                                                                                    
+void        meta_window_activate_with_workspace  (MetaWindow    *window,
+                                                  guint32        current_time,
+                                                  MetaWorkspace *workspace);   
+void        meta_window_make_fullscreen_internal (MetaWindow    *window);
 void        meta_window_make_fullscreen    (MetaWindow  *window);
 void        meta_window_unmake_fullscreen  (MetaWindow  *window);
 
@@ -486,10 +494,10 @@ void        meta_window_update_wireframe (MetaWindow *window,
 void        meta_window_end_wireframe (MetaWindow *window);
 
 void        meta_window_delete             (MetaWindow  *window,
-                                            Time         timestamp);
+                                            guint32      timestamp);
 void        meta_window_kill               (MetaWindow  *window);
 void        meta_window_focus              (MetaWindow  *window,
-                                            Time         timestamp);
+                                            guint32      timestamp);
 void        meta_window_raise              (MetaWindow  *window);
 void        meta_window_lower              (MetaWindow  *window);
 
@@ -498,7 +506,7 @@ void        meta_window_update_unfocused_button_grabs (MetaWindow *window);
 /* Sends a client message */
 void meta_window_send_icccm_message (MetaWindow *window,
                                      Atom        atom,
-                                     Time        timestamp);
+                                     guint32     timestamp);
 
 
 gboolean meta_window_configure_request (MetaWindow *window,
@@ -518,7 +526,7 @@ void meta_window_show_menu (MetaWindow *window,
                             int         root_x,
                             int         root_y,
                             int         button,
-                            Time        timestamp);
+                            guint32     timestamp);
 
 gboolean meta_window_titlebar_is_onscreen    (MetaWindow *window);
 void     meta_window_shove_titlebar_onscreen (MetaWindow *window);
@@ -572,7 +580,7 @@ MetaWindow* meta_window_find_root_ancestor    (MetaWindow *window);
 
 void meta_window_begin_grab_op (MetaWindow *window,
                                 MetaGrabOp  op,
-                                Time        timestamp);
+                                guint32     timestamp);
 
 void meta_window_update_keyboard_resize (MetaWindow *window,
                                          gboolean    update_cursor);
@@ -594,9 +602,12 @@ void meta_window_stack_just_below (MetaWindow *window,
                                    MetaWindow *below_this_one);
 
 void meta_window_set_user_time (MetaWindow *window,
-                                Time        timestamp);
+                                guint32     timestamp);
 
 void meta_window_set_demands_attention (MetaWindow *window);
 
 void meta_window_unset_demands_attention (MetaWindow *window);
+
+void meta_window_update_icon_now (MetaWindow *window);
+
 #endif
